# This short Python V2 & V3 demonstration program remotely controls a USB4 series board
# using serial commands to an FTDI serial port. V1.03  23/09/19

import serial    # serial inteface - you may need to use 'pip install pyserial' for this library
import time      # used for display
import sys       # display of data read back from the board.
import signal    # intercept SIGINT (Ctrl-C) to end demo.

# Define which FTDI port the USB4 device is using (Chage these according to your operating system and selected port mnumber.
SER_PORT_LIN = '/dev/ttyUSB0' # Linux version - check this using $> ls /dev/ttyUSB*
SER_PORT_WIN = 'COM25' # Windows version - check using device manager in control panel

BUFFER_SIZE = 1 # How many bytes to read back from board

# Introduction
print ("\nEasyDaq USB demonstration of the USB4 series boards")
print ("(Hit Ctrl-c to end)\n")
time.sleep(1)


# Open port
ser = serial.Serial(SER_PORT_WIN) #Open the port - select according to your OS. (Select WIN or LIN according to your operating system)
print (ser.name) # To check...

# Define a signal handler to catch when the user quits using Ctrl-C and then tidy up
def signal_handler(signal, frame):
 print('\n\n\n      *** Thank you for trying the EasyDaq USB4 series *** \nFor further information please visit http://www.easydaq.co.uk\n')
 MESSAGE = b'\x43\x00' # PIC port B to off
 time.sleep(0.100) # Just in case we were part way through sending a command pair of bytes.
 ser.write(MESSAGE)
 time.sleep(0.1)
 ser.close()
 sys.exit(0)

signal.signal(signal.SIGINT, signal_handler) # Register the signal handler

# Configure the USB4 ports for input/output
MESSAGE = b'\x42\xF0' # Set PIC port B lower 4 bits to output, upper 4 bits to I/P
ser.write(MESSAGE)
time.sleep(0.100) # Allow the board to settle.

# Send 0x0A and 0x05 to RLY1 to RLY4, whilst reading from PIC port B, upper 4 bits and displaying value

while True:
 MESSAGE = b'\x43\x05'; # Set PIC port B, lower 4 bits to 0x05
 ser.write(MESSAGE);
 time.sleep(0.100);
 
 MESSAGE = b'\x41\x00' # Read PIC port B;  
 ser.write(MESSAGE);
 sys.stdout.write("\r"+ time.ctime() + ":  " + format(ord(ser.read(BUFFER_SIZE)),'b').zfill(8));
 sys.stdout.flush();
 time.sleep(0.100)

 MESSAGE = b'\x43\x0a'; # Set PIC port B, lower 4 bits to 0x0a
 ser.write(MESSAGE);
 time.sleep(0.100);

 MESSAGE = b'\x41\x00' # Read PIC port B again;
 ser.write(MESSAGE);
 sys.stdout.write("\r"+ time.ctime() + ":  " + format(ord(ser.read(BUFFER_SIZE)),'b').zfill(8));
 sys.stdout.flush();
 time.sleep(0.100)

